@@ -6,6 +6,6 @@
     X <- formula[[2]]
     X <- eval(X, data, parent.frame())
     formula[[2]] <- NULL
-    P <- model.frame(formula, data, na.action = na.fail)
+    P <- model.frame(formula, data, na.action = na.pass)
     envfit(X, P, ...)
 }
